floating_toolbar/m3e_floating_toolbar_scroll_behavior library

Classes

M3EFloatingToolbarScrollBehavior
Integrates scroll events with the M3EFloatingToolbarState.
M3EFloatingToolbarScrollWrapper
A wrapper widget that listens to scroll notifications on its child scrollable and updates the associated behavior's state to slide the toolbar off-screen.
M3EFloatingToolbarState
The state of a floating toolbar, tracking its scroll offsets.
M3EFloatingToolbarVerticalNestedScroll
A wrapper widget that monitors scrolling and implements a simple expand/collapse threshold logic (typically used with vertical toolbars).

Enums

M3EFloatingToolbarExitDirection
Directions in which a floating toolbar can exit the screen.