M3EFloatingToolbarExitDirection enum

Directions in which a floating toolbar can exit the screen.

Inheritance
Available extensions

Values

top → const M3EFloatingToolbarExitDirection

Exit by moving upwards.

bottom → const M3EFloatingToolbarExitDirection

Exit by moving downwards.

start → const M3EFloatingToolbarExitDirection

Exit by moving towards the start (left in LTR).

end → const M3EFloatingToolbarExitDirection

Exit by moving towards the end (right in LTR).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<M3EFloatingToolbarExitDirection>
A constant List of the values in this enum, in order of their declaration.