M3EFloatingToolbarVerticalNestedScroll class

A wrapper widget that monitors scrolling and implements a simple expand/collapse threshold logic (typically used with vertical toolbars).

Inheritance

Constructors

M3EFloatingToolbarVerticalNestedScroll({Key? key, required bool expanded, required VoidCallback onExpand, required VoidCallback onCollapse, double expandScrollDistanceThreshold = M3EFloatingToolbarDefaults.scrollDistanceThreshold, double collapseScrollDistanceThreshold = M3EFloatingToolbarDefaults.scrollDistanceThreshold, bool reverseLayout = false, required Widget child})
const

Properties

child Widget
The scrollable child.
final
collapseScrollDistanceThreshold double
Distance threshold in dp to trigger collapse.
final
expanded bool
Whether the toolbar should currently be expanded.
final
expandScrollDistanceThreshold double
Distance threshold in dp to trigger expansion.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCollapse VoidCallback
Callback fired when the scroll distance threshold is crossed scrolling down.
final
onExpand VoidCallback
Callback fired when the scroll distance threshold is crossed scrolling up.
final
reverseLayout bool
Whether the scroll view layout is reversed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<M3EFloatingToolbarVerticalNestedScroll>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited