M3EFloatingToolbarDefaults class abstract

Token defaults and helper methods for Material 3 Expressive FloatingToolbar.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

standardColors(BuildContext context) M3EFloatingToolbarColors
Creates a standard M3EFloatingToolbarColors using the active ColorScheme.
standardFab({required VoidCallback onPressed, required Widget child, BuildContext? context, Object? heroTag}) Widget
Helper to create a standard Floating Action Button.
vibrantColors(BuildContext context) M3EFloatingToolbarColors
Creates a vibrant M3EFloatingToolbarColors using the active ColorScheme.
vibrantFab({required VoidCallback onPressed, required Widget child, BuildContext? context, Object? heroTag}) Widget
Helper to create a vibrant Floating Action Button.

Constants

collapsedElevation → const double
Default shadow elevation when toolbar is collapsed (no-FAB variants).
collapsedElevationWithFab → const double
Default shadow elevation when toolbar is collapsed (with-FAB variants).
containerShape → const ShapeBorder
Default shape of the floating toolbar container.
containerSize → const double
Container height (horizontal) or width (vertical).
contentPadding → const EdgeInsetsGeometry
Default padding for content within the floating toolbar.
expandedElevation → const double
Default shadow elevation when toolbar is expanded (no-FAB variants).
expandedElevationWithFab → const double
Default shadow elevation when toolbar is expanded (with-FAB variants).
fabBaselineSize → const double
FAB size when the floating toolbar is expanded (baseline size).
fabMediumSize → const double
FAB size when the floating toolbar is collapsed (medium size).
fabVariantTotalHeight → const double
Default layout container height for the horizontal FAB variant.
fabVariantTotalWidth → const double
Default layout container width for the vertical FAB variant.
screenOffset → const double
Standard external padding / screen offset from edge of container.
scrollDistanceThreshold → const double
Distance threshold in dp to trigger scroll exit or nested scroll expansion.
toolbarToFabGap → const double
Gap distance between the toolbar and the floating action button.