M3EHorizontalFloatingToolbar class
Material 3 Expressive Horizontal Floating Toolbar.
A standard horizontal toolbar that supports custom decorations and transitions.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- M3EHorizontalFloatingToolbar
Constructors
- M3EHorizontalFloatingToolbar({Key? key, required bool expanded, required Widget content, M3EFloatingToolbarScrollBehavior? scrollBehavior, Widget? leadingContent, Widget? trailingContent, VoidCallback? onExpandA11y, VoidCallback? onCollapseA11y, String? tooltip, M3EFloatingToolbarDecoration? decoration})
-
const
Properties
- content → Widget
-
The main content of the toolbar.
final
- decoration → M3EFloatingToolbarDecoration?
-
Styling and configuration overrides.
final
- expanded → bool
-
Whether the toolbar is expanded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leadingContent → Widget?
-
Optional widget displayed on the leading side when expanded.
final
- onCollapseA11y → VoidCallback?
-
Accessibility Collapse Callback.
final
- onExpandA11y → VoidCallback?
-
Accessibility Expand Callback.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollBehavior → M3EFloatingToolbarScrollBehavior?
-
Scroll behavior configuration to auto-exit the toolbar.
final
- tooltip → String?
-
Optional tooltip message shown on long-press (mobile) or hover (desktop).
final
- trailingContent → Widget?
-
Optional widget displayed on the trailing side when expanded.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< M3EHorizontalFloatingToolbar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited