M3EFloatingToolbarState class
The state of a floating toolbar, tracking its scroll offsets.
- Inheritance
-
- Object
- ChangeNotifier
- M3EFloatingToolbarState
Constructors
- M3EFloatingToolbarState()
- M3EFloatingToolbarState.create()
-
Factory constructor to instantiate a new M3EFloatingToolbarState with zero values.
factory
Properties
- collapsedFraction → double
-
Fraction of the toolbar that is collapsed (0.0 = fully visible, 1.0 = fully hidden).
no setter
- contentOffset ↔ double
-
The accumulated scroll distance consumed by the nested scroll system.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- offset ↔ double
-
The current translation offset of the toolbar (in pixels).
Coerced within
[offsetLimit, 0.0].getter/setter pair - offsetLimit ↔ double
-
The maximum negative translation offset (in pixels) for the exit animation.
Should always be less than or equal to 0.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited